#ifndef NT2_INCLUDE_FUNCTIONS_CUMSUM_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CUMSUM_HPP_INCLUDED

#include <nt2/swar/include/functions/cumsum.hpp>

#endif
